Module: Aws::BedrockDataAutomationRuntime
- Defined in:
- lib/aws-sdk-bedrockdataautomationruntime/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-bedrockdataautomationruntime/plugins/endpoints.rb,
lib/aws-sdk-bedrockdataautomationruntime/endpoint_provider.rb,
lib/aws-sdk-bedrockdataautomationruntime/client_api.rb,
lib/aws-sdk-bedrockdataautomationruntime/endpoints.rb,
lib/aws-sdk-bedrockdataautomationruntime/resource.rb,
lib/aws-sdk-bedrockdataautomationruntime/errors.rb,
lib/aws-sdk-bedrockdataautomationruntime/client.rb,
lib/aws-sdk-bedrockdataautomationruntime/types.rb,
lib/aws-sdk-bedrockdataautomationruntime.rb
Overview
This module provides support for Runtime for Amazon Bedrock Data Automation. This module is available in the
aws-sdk-bedrockdataautomationruntime gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
bedrock_data_automation_runtime = Aws::BedrockDataAutomationRuntime::Client.new
resp = bedrock_data_automation_runtime.get_data_automation_status(params)
See Client for more information.
Errors
Errors returned from Runtime for Amazon Bedrock Data Automation are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::BedrockDataAutomationRuntime::Errors::ServiceError
# rescues all Runtime for Amazon Bedrock Data Automation API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.28.0'