Class: Aws::BedrockDataAutomationRuntime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomationRuntime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomationruntime/client.rb,
sig/client.rbs
Overview
An API client for BedrockDataAutomationRuntime. To construct a client, you need to configure a :region and :credentials.
client = Aws::BedrockDataAutomationRuntime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetDataAutomationStatusResponseSuccess, _InvokeDataAutomationAsyncResponseSuccess, _InvokeDataAutomationResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_data_automation_status(params = {}) ⇒ Types::GetDataAutomationStatusResponse
API used to get data automation status.
-
#invoke_data_automation(params = {}) ⇒ Types::InvokeDataAutomationResponse
Sync API: Invoke data automation.
-
#invoke_data_automation_async(params = {}) ⇒ Types::InvokeDataAutomationAsyncResponse
Async API: Invoke data automation.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
816 817 818 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 816 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
819 820 821 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 819 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 789 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomationRuntime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomationruntime' context[:gem_version] = '1.28.0' Seahorse::Client::Request.new(handlers, context) end |
#get_data_automation_status(params = {}) ⇒ Types::GetDataAutomationStatusResponse
API used to get data automation status.
93 |
# File 'sig/client.rbs', line 93
def get_data_automation_status: (
|
#invoke_data_automation(params = {}) ⇒ Types::InvokeDataAutomationResponse
Sync API: Invoke data automation.
105 |
# File 'sig/client.rbs', line 105
def invoke_data_automation: (
|
#invoke_data_automation_async(params = {}) ⇒ Types::InvokeDataAutomationAsyncResponse
Async API: Invoke data automation.
137 |
# File 'sig/client.rbs', line 137
def invoke_data_automation_async: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
190 |
# File 'sig/client.rbs', line 190
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
199 |
# File 'sig/client.rbs', line 199
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
214 |
# File 'sig/client.rbs', line 214
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
809 810 811 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 809 def waiter_names [] end |