Class: Aws::BedrockDataAutomationRuntime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockDataAutomationRuntime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockdataautomationruntime/client.rb
Overview
An API client for BedrockDataAutomationRuntime. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockDataAutomationRuntime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_data_automation_status(params = {}) ⇒ Types::GetDataAutomationStatusResponse
API used to get data automation status.
-
#invoke_data_automation(params = {}) ⇒ Types::InvokeDataAutomationResponse
Sync API: Invoke data automation.
-
#invoke_data_automation_async(params = {}) ⇒ Types::InvokeDataAutomationAsyncResponse
Async API: Invoke data automation.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource.
-
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
816 817 818 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 816 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
819 820 821 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 819 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 789 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockDataAutomationRuntime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockdataautomationruntime' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#get_data_automation_status(params = {}) ⇒ Types::GetDataAutomationStatusResponse
API used to get data automation status.
519 520 521 522 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 519 def get_data_automation_status(params = {}, = {}) req = build_request(:get_data_automation_status, params) req.send_request() end |
#invoke_data_automation(params = {}) ⇒ Types::InvokeDataAutomationResponse
Sync API: Invoke data automation.
593 594 595 596 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 593 def invoke_data_automation(params = {}, = {}) req = build_request(:invoke_data_automation, params) req.send_request() end |
#invoke_data_automation_async(params = {}) ⇒ Types::InvokeDataAutomationAsyncResponse
Async API: Invoke data automation.
693 694 695 696 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 693 def invoke_data_automation_async(params = {}, = {}) req = build_request(:invoke_data_automation_async, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for an Amazon Bedrock Data Automation resource
723 724 725 726 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 723 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tag an Amazon Bedrock Data Automation resource
754 755 756 757 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 754 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untag an Amazon Bedrock Data Automation resource
780 781 782 783 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 780 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
809 810 811 |
# File 'lib/aws-sdk-bedrockdataautomationruntime/client.rb', line 809 def waiter_names [] end |